==> muchscript-0.1.3.tar.gz: muchscript-0.1.3/muchscript/muchscript.py <==

'''

░░░░░░░░░▄░░░░░░░░░░░░░░▄░░░░
░░░░░░░░▌▒█░░░░░░░░░░░▄▀▒▌░░░
░░░░░░░░▌▒▒█░░░░░░░░▄▀▒▒▒▐░░░
░░░░░░░▐▄▀▒▒▀▀▀▀▄▄▄▀▒▒▒▒▒▐░░░
░░░░░▄▄▀▒░▒▒▒▒▒▒▒▒▒█▒▒▄█▒▐░░░
░░░▄▀▒▒▒░░░▒▒▒░░░▒▒▒▀██▀▒▌░░░ 
░░▐▒▒▒▄▄▒▒▒▒░░░▒▒▒▒▒▒▒▀▄▒▒▌░░
░░▌░░▌█▀▒▒▒▒▒▄▀█▄▒▒▒▒▒▒▒█▒▐░░
░▐░░░▒▒▒▒▒▒▒▒▌██▀▒▒░░░▒▒▒▀▄▌░
░▌░▒▄██▄▒▒▒▒▒▒▒▒▒░░░░░░▒▒▒▒▌░
▀▒▀▐▄█▄█▌▄░▀▒▒░░░░░░░░░░▒▒▒▐░
▐▒▒▐▀▐▀▒░▄▄▒▄▒▒▒▒▒▒░▒░▒░▒▒▒▒▌
▐▒▒▒▀▀▄▄▒▒▒▄▒▒▒▒▒▒▒▒░▒░▒░▒▒▐░
░▌▒▒▒▒▒▒▀▀▀▒▒▒▒▒▒░▒░▒░▒░▒▒▒▌░
░▐▒▒▒▒▒▒▒▒▒▒▒▒▒▒░▒░▒░▒▒▄▒▒▐░░
░░▀▄▒▒▒▒▒▒▒▒▒▒▒░▒░▒░▒▄▒▒▒▒▌░░
░░░░▀▄▒▒▒▒▒▒▒▒▒▒▄▄▄▀▒▒▒▒▄▀░░░
░░░░░░▀▄▄▄▄▄▄▀▀▀▒▒▒▒▒▄▄▀░░░░░
░░░░░░░░░▒▒▒▒▒▒▒▒▒▒▀▀░░░░░░░░

MUCHSCRIPT MADE FOR DOGE
INSPIRED BY DOGE AND ELON MUSK
MADE WITH LOVE AND STRESS by sBlip
@ MUCHSCRIPT 0.1.3 BETA 2021

MUCH WOW. MUCH COOL. MUCH CRYPTO.

'''

from . import run
import readline
import sys

try:
    if sys.argv[1]:
        f = open(sys.argv[1], 'r')

        text = f.read()
        result, error = run.run('<stdin>', text)

        if error:
            print(error.as_string())
        elif result:
            if len(result.elements) == 1:
                pass
            else:
                pass
except IndexError:
    # pass
    print("")
    print("MUCHSCRIPT 0.1 (BETA)")
    print("Made by muchscript inc. © 2021")
    print("Inspired by Doge and Elon musk")
    print("MUCH WOW. MUCH COOL. MUCH CRYPTO.")
    print("")

    index = 0

    while True:
        try:
            text = input('[MUCHSCRIPT]: ')
            if text.strip() == "":
                continue
            result, error = run.run('<stdin>', text)

            if error:
                print(error.as_string())
            elif result:
                if len(result.elements) == 1:
                    print(repr(result.elements[0]))
                else:
                    print(repr(result))

            index += 1
            
        except KeyboardInterrupt:
            print("Quitting...")
            exit()

==> muchscript-0.1.4.tar.gz: muchscript-0.1.4/muchscript/muchscript.py <==

'''

░░░░░░░░░▄░░░░░░░░░░░░░░▄░░░░
░░░░░░░░▌▒█░░░░░░░░░░░▄▀▒▌░░░
░░░░░░░░▌▒▒█░░░░░░░░▄▀▒▒▒▐░░░
░░░░░░░▐▄▀▒▒▀▀▀▀▄▄▄▀▒▒▒▒▒▐░░░
░░░░░▄▄▀▒░▒▒▒▒▒▒▒▒▒█▒▒▄█▒▐░░░
░░░▄▀▒▒▒░░░▒▒▒░░░▒▒▒▀██▀▒▌░░░ 
░░▐▒▒▒▄▄▒▒▒▒░░░▒▒▒▒▒▒▒▀▄▒▒▌░░
░░▌░░▌█▀▒▒▒▒▒▄▀█▄▒▒▒▒▒▒▒█▒▐░░
░▐░░░▒▒▒▒▒▒▒▒▌██▀▒▒░░░▒▒▒▀▄▌░
░▌░▒▄██▄▒▒▒▒▒▒▒▒▒░░░░░░▒▒▒▒▌░
▀▒▀▐▄█▄█▌▄░▀▒▒░░░░░░░░░░▒▒▒▐░
▐▒▒▐▀▐▀▒░▄▄▒▄▒▒▒▒▒▒░▒░▒░▒▒▒▒▌
▐▒▒▒▀▀▄▄▒▒▒▄▒▒▒▒▒▒▒▒░▒░▒░▒▒▐░
░▌▒▒▒▒▒▒▀▀▀▒▒▒▒▒▒░▒░▒░▒░▒▒▒▌░
░▐▒▒▒▒▒▒▒▒▒▒▒▒▒▒░▒░▒░▒▒▄▒▒▐░░
░░▀▄▒▒▒▒▒▒▒▒▒▒▒░▒░▒░▒▄▒▒▒▒▌░░
░░░░▀▄▒▒▒▒▒▒▒▒▒▒▄▄▄▀▒▒▒▒▄▀░░░
░░░░░░▀▄▄▄▄▄▄▀▀▀▒▒▒▒▒▄▄▀░░░░░
░░░░░░░░░▒▒▒▒▒▒▒▒▒▒▀▀░░░░░░░░

MUCHSCRIPT MADE FOR DOGE
INSPIRED BY DOGE AND ELON MUSK
MADE WITH LOVE AND STRESS by sBlip
@ MUCHSCRIPT 0.1.3 BETA 2021

MUCH WOW. MUCH COOL. MUCH CRYPTO.

'''

from . import run
import readline
import sys

try:
    if sys.argv[1]:
        f = open(sys.argv[1], 'r')

        text = f.read()
        result, error = run.run('<stdin>', text)

        if error:
            print(error.as_string())
        elif result:
            if len(result.elements) == 1:
                pass
            else:
                pass
except IndexError:
    # pass
    print("")
    print("MUCHSCRIPT 0.1.3 (BETA)")
    print("Made by Shaurya Pratap Singh © 2021")
    print("Inspired by Doge and Elon musk")
    print("MUCH WOW. MUCH COOL. MUCH CRYPTO.")
    print("")

    index = 0

    while True:
        try:
            text = input('[MUCHSCRIPT]: ')
            if text.strip() == "":
                continue
            result, error = run.run('<stdin>', text)

            if error:
                print(error.as_string())
            elif result:
                if len(result.elements) == 1:
                    print(repr(result.elements[0]))
                else:
                    print(repr(result))

            index += 1
            
        except KeyboardInterrupt:
            print("Quitting...")
            exit()
